@@ -37,6 +37,8 @@ def setup():
     )
     winreg.CloseKey(key_handle)
 
+    print('Refresh your cmd.exe for complete install.')
+
 
 def uninstall():
     key_handle = winreg.OpenKeyEx(
@@ -47,7 +49,7 @@ def uninstall():
 
     os.remove(HOME_PATH + '\\.macros.doskey')
 
-    print('Refresh you cmd.exe for complete uninstall.')
+    print('Refresh your cmd.exe for complete uninstall.')
 
 
 def main():
